Module traits

Module traits 

the traits defining compatible rules within the framework

Traits

RawPoint
RawProgram
RawSpace
The RawSpace trait defines the basic interface for any compatible stores used within the crate.
RuleSpace
The RuleSpace extends the RawSpace trait to introduce rule-specific functionality. It provides a method to retrieve the tail of a rule given its head.