Module traits
rstm_
programs
0.1.0
Module traits
Module Items
Traits
In crate rstm_
programs
rstm_programs
Module
traits
the traits defining compatible rules within the framework
Traits

RawPoint
RawProgram
RawSpace
The
RawSpace
trait defines the basic interface for any compatible stores used within the crate.
Rule
Space
The
RuleSpace
extends the
RawSpace
trait to introduce rule-specific functionality. It provides a method to retrieve the tail of a rule given its head.